pub fn build_program_source(
code: &str,
connectors: &[ConnectorDescription],
options: &ProgramSourceOptions,
) -> Result<String, String>Expand description
Builds the shared body used by local and remote Code Mode executors.
pub fn build_program_source(
code: &str,
connectors: &[ConnectorDescription],
options: &ProgramSourceOptions,
) -> Result<String, String>Builds the shared body used by local and remote Code Mode executors.