pub fn generate_types(description: &ConnectorDescription) -> StringExpand description
Generates the TypeScript declarations shown to the model for a connector.
pub fn generate_types(description: &ConnectorDescription) -> StringGenerates the TypeScript declarations shown to the model for a connector.